@@ -1,5 +1,5 @@
 def basic_log_tests(client):
-    a = client.logs.create(game_id=2, player_number=42)
+    a = client.logs.create(game=2, player_number=42)
     print()
     print(a)
 
@@ -13,6 +13,6 @@ def basic_log_tests(client):
     d = client.logs.update(id=a.id, player_number=13)
     print()
     print(d)
-    
+
     e = client.logs.delete(id=a.id)
-    print(e)
\ No newline at end of file
+    print(e)
