@@ -6,13 +6,15 @@ from .http_client import AsyncHttpClient, HttpClient
 
 
 class BaseClientWrapper:
-    def __init__(self, *, api_key: str, base_url: str, timeout: typing.Optional[float] = None):
+    def __init__(
+        self, *, api_key: str, base_url: str, timeout: typing.Optional[float] = None
+    ):
         self.api_key = api_key
         self._base_url = base_url
         self._timeout = timeout
 
     def get_headers(self) -> typing.Dict[str, str]:
-        headers: typing.Dict[str, str] = {}        
+        headers: typing.Dict[str, str] = {}
         headers["Authorization"] = f"Token  {self.api_key}"
         return headers
 
@@ -25,7 +27,12 @@ class BaseClientWrapper:
 
 class SyncClientWrapper(BaseClientWrapper):
     def __init__(
-        self, *, api_key: str, base_url: str, timeout: typing.Optional[float] = None, httpx_client: httpx.Client
+        self,
+        *,
+        api_key: str,
+        base_url: str,
+        timeout: typing.Optional[float] = None,
+        httpx_client: httpx.Client,
     ):
         super().__init__(api_key=api_key, base_url=base_url, timeout=timeout)
         self.httpx_client = HttpClient(
@@ -38,7 +45,12 @@ class SyncClientWrapper(BaseClientWrapper):
 
 class AsyncClientWrapper(BaseClientWrapper):
     def __init__(
-        self, *, api_key: str, base_url: str, timeout: typing.Optional[float] = None, httpx_client: httpx.AsyncClient
+        self,
+        *,
+        api_key: str,
+        base_url: str,
+        timeout: typing.Optional[float] = None,
+        httpx_client: httpx.AsyncClient,
     ):
         super().__init__(api_key=api_key, base_url=base_url, timeout=timeout)
         self.httpx_client = AsyncHttpClient(
@@ -46,4 +58,4 @@ class AsyncClientWrapper(BaseClientWrapper):
             base_headers=self.get_headers(),
             base_timeout=self.get_timeout(),
             base_url=self.get_base_url(),
-        )
\ No newline at end of file
+        )
