@@ -11,7 +11,9 @@ def serialize_datetime(v: dt.datetime) -> str:
     """
 
     def _serialize_zoned_datetime(v: dt.datetime) -> str:
-        if v.tzinfo is not None and v.tzinfo.tzname(None) == dt.timezone.utc.tzname(None):
+        if v.tzinfo is not None and v.tzinfo.tzname(None) == dt.timezone.utc.tzname(
+            None
+        ):
             # UTC is a special case where we use "Z" at the end instead of "+00:00"
             return v.isoformat().replace("+00:00", "Z")
         else:
@@ -23,4 +25,4 @@ def serialize_datetime(v: dt.datetime) -> str:
     else:
         local_tz = dt.datetime.now().astimezone().tzinfo
         localized_dt = v.replace(tzinfo=local_tz)
-        return _serialize_zoned_datetime(localized_dt)
\ No newline at end of file
+        return _serialize_zoned_datetime(localized_dt)
