@@ -1,6 +1,5 @@
 import asyncio
 import email.utils
-import json
 import re
 import time
 import typing
@@ -75,7 +74,9 @@ def _retry_timeout(response: httpx.Response, retries: int) -> float:
         return retry_after
 
     # Apply exponential backoff, capped at MAX_RETRY_DELAY_SECONDS.
-    retry_delay = min(INITIAL_RETRY_DELAY_SECONDS * pow(2.0, retries), MAX_RETRY_DELAY_SECONDS)
+    retry_delay = min(
+        INITIAL_RETRY_DELAY_SECONDS * pow(2.0, retries), MAX_RETRY_DELAY_SECONDS
+    )
 
     # Add a randomness / jitter to the retry delay to avoid overwhelming the server with retries.
     timeout = retry_delay * (1 - 0.25 * random())
@@ -88,7 +89,8 @@ def _should_retry(response: httpx.Response) -> bool:
 
 
 def remove_omit_from_dict(
-    original: typing.Dict[str, typing.Optional[typing.Any]], omit: typing.Optional[typing.Any]
+    original: typing.Dict[str, typing.Optional[typing.Any]],
+    omit: typing.Optional[typing.Any],
 ) -> typing.Dict[str, typing.Any]:
     if omit is None:
         return original
@@ -160,7 +162,9 @@ class HttpClient:
     def get_base_url(self, maybe_base_url: typing.Optional[str]) -> str:
         base_url = self.base_url if maybe_base_url is None else maybe_base_url
         if base_url is None:
-            raise ValueError("A base_url is required to make this request, please provide one and try again.")
+            raise ValueError(
+                "A base_url is required to make this request, please provide one and try again."
+            )
         return base_url
 
     def request(
@@ -172,8 +176,12 @@ class HttpClient:
         params: typing.Optional[typing.Dict[str, typing.Any]] = None,
         json: typing.Optional[typing.Any] = None,
         data: typing.Optional[typing.Any] = None,
-        content: typing.Optional[typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]] = None,
-        files: typing.Optional[typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]] = None,
+        content: typing.Optional[
+            typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]
+        ] = None,
+        files: typing.Optional[
+            typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]
+        ] = None,
         headers: typing.Optional[typing.Dict[str, typing.Any]] = None,
         request_options: typing.Optional[RequestOptions] = None,
         retries: int = 0,
@@ -182,11 +190,14 @@ class HttpClient:
         base_url = self.get_base_url(base_url)
         timeout = (
             request_options.get("timeout_in_seconds")
-            if request_options is not None and request_options.get("timeout_in_seconds") is not None
+            if request_options is not None
+            and request_options.get("timeout_in_seconds") is not None
             else self.base_timeout
         )
 
-        json_body, data_body = get_request_body(json=json, data=data, request_options=request_options, omit=omit)
+        json_body, data_body = get_request_body(
+            json=json, data=data, request_options=request_options, omit=omit
+        )
 
         response = self.httpx_client.request(
             method=method,
@@ -196,7 +207,11 @@ class HttpClient:
                     {
                         **self.base_headers,
                         **(headers if headers is not None else {}),
-                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
+                        **(
+                            request_options.get("additional_headers", {})
+                            if request_options is not None
+                            else {}
+                        ),
                     }
                 )
             ),
@@ -207,7 +222,9 @@ class HttpClient:
                             {
                                 **(params if params is not None else {}),
                                 **(
-                                    request_options.get("additional_query_parameters", {})
+                                    request_options.get(
+                                        "additional_query_parameters", {}
+                                    )
                                     if request_options is not None
                                     else {}
                                 ),
@@ -220,11 +237,15 @@ class HttpClient:
             json=json_body,
             data=data_body,
             content=content,
-            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files)) if files is not None else None,
+            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files))
+            if files is not None
+            else None,
             timeout=timeout,
         )
 
-        max_retries: int = request_options.get("max_retries", 0) if request_options is not None else 0
+        max_retries: int = (
+            request_options.get("max_retries", 0) if request_options is not None else 0
+        )
         if _should_retry(response=response):
             if max_retries > retries:
                 time.sleep(_retry_timeout(response=response, retries=retries))
@@ -254,8 +275,12 @@ class HttpClient:
         params: typing.Optional[typing.Dict[str, typing.Any]] = None,
         json: typing.Optional[typing.Any] = None,
         data: typing.Optional[typing.Any] = None,
-        content: typing.Optional[typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]] = None,
-        files: typing.Optional[typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]] = None,
+        content: typing.Optional[
+            typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]
+        ] = None,
+        files: typing.Optional[
+            typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]
+        ] = None,
         headers: typing.Optional[typing.Dict[str, typing.Any]] = None,
         request_options: typing.Optional[RequestOptions] = None,
         retries: int = 0,
@@ -264,11 +289,14 @@ class HttpClient:
         base_url = self.get_base_url(base_url)
         timeout = (
             request_options.get("timeout_in_seconds")
-            if request_options is not None and request_options.get("timeout_in_seconds") is not None
+            if request_options is not None
+            and request_options.get("timeout_in_seconds") is not None
             else self.base_timeout
         )
 
-        json_body, data_body = get_request_body(json=json, data=data, request_options=request_options, omit=omit)
+        json_body, data_body = get_request_body(
+            json=json, data=data, request_options=request_options, omit=omit
+        )
 
         with self.httpx_client.stream(
             method=method,
@@ -278,7 +306,11 @@ class HttpClient:
                     {
                         **self.base_headers,
                         **(headers if headers is not None else {}),
-                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
+                        **(
+                            request_options.get("additional_headers", {})
+                            if request_options is not None
+                            else {}
+                        ),
                     }
                 )
             ),
@@ -289,7 +321,9 @@ class HttpClient:
                             {
                                 **(params if params is not None else {}),
                                 **(
-                                    request_options.get("additional_query_parameters", {})
+                                    request_options.get(
+                                        "additional_query_parameters", {}
+                                    )
                                     if request_options is not None
                                     else {}
                                 ),
@@ -302,7 +336,9 @@ class HttpClient:
             json=json_body,
             data=data_body,
             content=content,
-            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files)) if files is not None else None,
+            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files))
+            if files is not None
+            else None,
             timeout=timeout,
         ) as stream:
             yield stream
@@ -325,7 +361,9 @@ class AsyncHttpClient:
     def get_base_url(self, maybe_base_url: typing.Optional[str]) -> str:
         base_url = self.base_url if maybe_base_url is None else maybe_base_url
         if base_url is None:
-            raise ValueError("A base_url is required to make this request, please provide one and try again.")
+            raise ValueError(
+                "A base_url is required to make this request, please provide one and try again."
+            )
         return base_url
 
     async def request(
@@ -337,8 +375,12 @@ class AsyncHttpClient:
         params: typing.Optional[typing.Dict[str, typing.Any]] = None,
         json: typing.Optional[typing.Any] = None,
         data: typing.Optional[typing.Any] = None,
-        content: typing.Optional[typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]] = None,
-        files: typing.Optional[typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]] = None,
+        content: typing.Optional[
+            typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]
+        ] = None,
+        files: typing.Optional[
+            typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]
+        ] = None,
         headers: typing.Optional[typing.Dict[str, typing.Any]] = None,
         request_options: typing.Optional[RequestOptions] = None,
         retries: int = 0,
@@ -347,11 +389,14 @@ class AsyncHttpClient:
         base_url = self.get_base_url(base_url)
         timeout = (
             request_options.get("timeout_in_seconds")
-            if request_options is not None and request_options.get("timeout_in_seconds") is not None
+            if request_options is not None
+            and request_options.get("timeout_in_seconds") is not None
             else self.base_timeout
         )
 
-        json_body, data_body = get_request_body(json=json, data=data, request_options=request_options, omit=omit)
+        json_body, data_body = get_request_body(
+            json=json, data=data, request_options=request_options, omit=omit
+        )
 
         # Add the input to each of these and do None-safety checks
         response = await self.httpx_client.request(
@@ -362,7 +407,11 @@ class AsyncHttpClient:
                     {
                         **self.base_headers,
                         **(headers if headers is not None else {}),
-                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
+                        **(
+                            request_options.get("additional_headers", {})
+                            if request_options is not None
+                            else {}
+                        ),
                     }
                 )
             ),
@@ -373,7 +422,9 @@ class AsyncHttpClient:
                             {
                                 **(params if params is not None else {}),
                                 **(
-                                    request_options.get("additional_query_parameters", {})
+                                    request_options.get(
+                                        "additional_query_parameters", {}
+                                    )
                                     if request_options is not None
                                     else {}
                                 ),
@@ -386,11 +437,15 @@ class AsyncHttpClient:
             json=json_body,
             data=data_body,
             content=content,
-            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files)) if files is not None else None,
+            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files))
+            if files is not None
+            else None,
             timeout=timeout,
         )
 
-        max_retries: int = request_options.get("max_retries", 0) if request_options is not None else 0
+        max_retries: int = (
+            request_options.get("max_retries", 0) if request_options is not None else 0
+        )
         if _should_retry(response=response):
             if max_retries > retries:
                 await asyncio.sleep(_retry_timeout(response=response, retries=retries))
@@ -419,8 +474,12 @@ class AsyncHttpClient:
         params: typing.Optional[typing.Dict[str, typing.Any]] = None,
         json: typing.Optional[typing.Any] = None,
         data: typing.Optional[typing.Any] = None,
-        content: typing.Optional[typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]] = None,
-        files: typing.Optional[typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]] = None,
+        content: typing.Optional[
+            typing.Union[bytes, typing.Iterator[bytes], typing.AsyncIterator[bytes]]
+        ] = None,
+        files: typing.Optional[
+            typing.Dict[str, typing.Optional[typing.Union[File, typing.List[File]]]]
+        ] = None,
         headers: typing.Optional[typing.Dict[str, typing.Any]] = None,
         request_options: typing.Optional[RequestOptions] = None,
         retries: int = 0,
@@ -429,11 +488,14 @@ class AsyncHttpClient:
         base_url = self.get_base_url(base_url)
         timeout = (
             request_options.get("timeout_in_seconds")
-            if request_options is not None and request_options.get("timeout_in_seconds") is not None
+            if request_options is not None
+            and request_options.get("timeout_in_seconds") is not None
             else self.base_timeout
         )
 
-        json_body, data_body = get_request_body(json=json, data=data, request_options=request_options, omit=omit)
+        json_body, data_body = get_request_body(
+            json=json, data=data, request_options=request_options, omit=omit
+        )
 
         async with self.httpx_client.stream(
             method=method,
@@ -443,7 +505,11 @@ class AsyncHttpClient:
                     {
                         **self.base_headers,
                         **(headers if headers is not None else {}),
-                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
+                        **(
+                            request_options.get("additional_headers", {})
+                            if request_options is not None
+                            else {}
+                        ),
                     }
                 )
             ),
@@ -454,7 +520,9 @@ class AsyncHttpClient:
                             {
                                 **(params if params is not None else {}),
                                 **(
-                                    request_options.get("additional_query_parameters", {})
+                                    request_options.get(
+                                        "additional_query_parameters", {}
+                                    )
                                     if request_options is not None
                                     else {}
                                 ),
@@ -467,7 +535,9 @@ class AsyncHttpClient:
             json=json_body,
             data=data_body,
             content=content,
-            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files)) if files is not None else None,
+            files=convert_file_dict_to_httpx_tuples(remove_none_from_dict(files))
+            if files is not None
+            else None,
             timeout=timeout,
         ) as stream:
-            yield stream
\ No newline at end of file
+            yield stream
