@@ -5,7 +5,9 @@ from .pydantic_utilities import pydantic_v1
 
 
 # Flattens dicts to be of the form {"key[subkey][subkey2]": value} where value is not a dict
-def traverse_query_dict(dict_flat: Dict[str, Any], key_prefix: Optional[str] = None) -> Dict[str, Any]:
+def traverse_query_dict(
+    dict_flat: Dict[str, Any], key_prefix: Optional[str] = None
+) -> Dict[str, Any]:
     result = {}
     for k, v in dict_flat.items():
         key = f"{key_prefix}[{k}]" if key_prefix is not None else k
@@ -28,4 +30,8 @@ def single_query_encoder(query_key: str, query_value: Any) -> Dict[str, Any]:
 
 
 def encode_query(query: Optional[Dict[str, Any]]) -> Optional[Dict[str, Any]]:
-    return dict(ChainMap(*[single_query_encoder(k, v) for k, v in query.items()])) if query is not None else None
\ No newline at end of file
+    return (
+        dict(ChainMap(*[single_query_encoder(k, v) for k, v in query.items()]))
+        if query is not None
+        else None
+    )
