@@ -3,7 +3,7 @@ import datetime as dt
 from json.decoder import JSONDecodeError
 
 from ..core.api_error import ApiError
-from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
+from ..core.client_wrapper import SyncClientWrapper
 from ..core.jsonable_encoder import jsonable_encoder
 from ..core.pydantic_utilities import pydantic_v1
 from ..core.request_options import RequestOptions
@@ -12,41 +12,48 @@ from ..types.event import Event
 # this is used as the default value for optional parameters
 OMIT = typing.cast(typing.Any, ...)
 
+
 class EventsClient:
     def __init__(self, *, client_wrapper: SyncClientWrapper):
         self._client_wrapper = client_wrapper
 
-    def get(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> Event:
+    def get(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> Event:
         """
         Examples
         --------
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/events/{jsonable_encoder(id)}/", method="GET", request_options=request_options
+            f"api/events/{jsonable_encoder(id)}/",
+            method="GET",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
                 return pydantic_v1.parse_obj_as(Event, _response.json())  # type: ignore
             _response_json = _response.json()
-            
+
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
-    def delete(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> None:
+    def delete(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> None:
         """
         Delete an event.
 
         <Warning>This action can't be undone!</Warning>
 
-        You will need to supply the events's unique ID. You can find the ID in 
-        the django admin panel or in the events settings in the UI. 
+        You will need to supply the events's unique ID. You can find the ID in
+        the django admin panel or in the events settings in the UI.
         Parameters
         ----------
         id : int
@@ -64,7 +71,7 @@ class EventsClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.annotations.delete(
@@ -72,7 +79,9 @@ class EventsClient:
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/events/{jsonable_encoder(id)}/", method="DELETE", request_options=request_options
+            f"api/events/{jsonable_encoder(id)}/",
+            method="DELETE",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
@@ -91,6 +100,7 @@ class EventsClient:
         end_day: typing.Optional[dt.date] = OMIT,
         country: typing.Optional[str] = OMIT,
         location: typing.Optional[str] = OMIT,
+        event_folder: typing.Optional[str] = OMIT,
         comment: typing.Optional[str] = OMIT,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> Event:
@@ -143,7 +153,7 @@ class EventsClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.annotations.update(
@@ -179,6 +189,7 @@ class EventsClient:
                 "end_day": end_day,
                 "country": country,
                 "location": location,
+                "event_folder": event_folder,
                 "comment": comment,
             },
             request_options=request_options,
@@ -192,7 +203,9 @@ class EventsClient:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
-    def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.List[Event]:
+    def list(
+        self, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> typing.List[Event]:
         """
         List all annotations for a task.
 
@@ -216,7 +229,7 @@ class EventsClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.annotations.list(
@@ -224,7 +237,7 @@ class EventsClient:
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/events/", method="GET", request_options=request_options
+            "api/events/", method="GET", request_options=request_options
         )
         try:
             if 200 <= _response.status_code < 300:
@@ -242,6 +255,7 @@ class EventsClient:
         end_day: typing.Optional[dt.date] = OMIT,
         country: typing.Optional[str] = OMIT,
         location: typing.Optional[str] = OMIT,
+        event_folder: typing.Optional[str] = OMIT,
         comment: typing.Optional[str] = OMIT,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> Event:
@@ -251,12 +265,12 @@ class EventsClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/events/",
+            "api/events/",
             method="POST",
             json={
                 "name": name,
@@ -264,6 +278,7 @@ class EventsClient:
                 "end_day": end_day,
                 "country": country,
                 "location": location,
+                "event_folder": event_folder,
                 "comment": comment,
             },
             request_options=request_options,
@@ -289,12 +304,12 @@ class EventsClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/events/",
+            "api/events/",
             method="POST",
             json=event_list,
             request_options=request_options,
@@ -306,4 +321,4 @@ class EventsClient:
             _response_json = _response.json()
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
-        raise ApiError(status_code=_response.status_code, body=_response_json)
\ No newline at end of file
+        raise ApiError(status_code=_response.status_code, body=_response_json)
