@@ -11,41 +11,48 @@ from ..types.log_status import LogStatus
 # this is used as the default value for optional parameters
 OMIT = typing.cast(typing.Any, ...)
 
+
 class LogStatusClient:
     def __init__(self, *, client_wrapper: SyncClientWrapper):
         self._client_wrapper = client_wrapper
 
-    def get(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> LogStatus:
+    def get(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> LogStatus:
         """
         Examples
         --------
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/log-status/{jsonable_encoder(id)}/", method="GET", request_options=request_options
+            f"api/log-status/{jsonable_encoder(id)}/",
+            method="GET",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
                 return pydantic_v1.parse_obj_as(LogStatus, _response.json())  # type: ignore
             _response_json = _response.json()
-            
+
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
-    def delete(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> None:
+    def delete(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> None:
         """
         Delete the log status for one log.
 
         <Warning>This action can't be undone!</Warning>
 
-        You will need to supply the logs's unique ID. You can find the ID in 
-        the django admin panel or in the log settings in the UI. 
+        You will need to supply the logs's unique ID. You can find the ID in
+        the django admin panel or in the log settings in the UI.
         Parameters
         ----------
         id : int
@@ -63,7 +70,7 @@ class LogStatusClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.annotations.delete(
@@ -71,7 +78,9 @@ class LogStatusClient:
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/log-status/{jsonable_encoder(id)}/", method="DELETE", request_options=request_options
+            f"api/log-status/{jsonable_encoder(id)}/",
+            method="DELETE",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
@@ -85,9 +94,14 @@ class LogStatusClient:
         self,
         log: int,
         *,
+        FrameInfo: typing.Optional[int] = OMIT,
+        RobotInfo: typing.Optional[int] = OMIT,
+        AudioData: typing.Optional[int] = OMIT,
         BallModel: typing.Optional[int] = OMIT,
         BallCandidates: typing.Optional[int] = OMIT,
         BallCandidatesTop: typing.Optional[int] = OMIT,
+        BehaviorStateComplete: typing.Optional[int] = OMIT,
+        BehaviorStateSparse: typing.Optional[int] = OMIT,
         CameraMatrix: typing.Optional[int] = OMIT,
         CameraMatrixTop: typing.Optional[int] = OMIT,
         FieldPercept: typing.Optional[int] = OMIT,
@@ -100,7 +114,14 @@ class LogStatusClient:
         ShortLinePercept: typing.Optional[int] = OMIT,
         ScanLineEdgelPercept: typing.Optional[int] = OMIT,
         ScanLineEdgelPerceptTop: typing.Optional[int] = OMIT,
+        TeamMessageDecision: typing.Optional[int] = OMIT,
+        TeamState: typing.Optional[int] = OMIT,
         OdometryData: typing.Optional[int] = OMIT,
+        Image: typing.Optional[int] = OMIT,
+        ImageTop: typing.Optional[int] = OMIT,
+        ImageJPEG: typing.Optional[int] = OMIT,
+        ImageJPEGTop: typing.Optional[int] = OMIT,
+        WhistlePercept: typing.Optional[int] = OMIT,
         IMUData: typing.Optional[int] = OMIT,
         FSRData: typing.Optional[int] = OMIT,
         ButtonData: typing.Optional[int] = OMIT,
@@ -110,23 +131,22 @@ class LogStatusClient:
         MotionStatus: typing.Optional[int] = OMIT,
         MotorJointData: typing.Optional[int] = OMIT,
         GyrometerData: typing.Optional[int] = OMIT,
-        num_cognition_frames: typing.Optional[int] = OMIT,
         num_motion_frames: typing.Optional[int] = OMIT,
-        num_jpg_bottom: typing.Optional[int] = OMIT,
-        num_jpg_top: typing.Optional[int] = OMIT,
-        num_bottom: typing.Optional[int] = OMIT,
-        num_top: typing.Optional[int] = OMIT,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> LogStatus:
-        """
-        """
+        """ """
         _response = self._client_wrapper.httpx_client.request(
             f"api/log-status/{jsonable_encoder(log)}/",
             method="PATCH",
             json={
+                "FrameInfo": FrameInfo,
+                "RobotInfo": RobotInfo,
+                "AudioData": AudioData,
                 "BallModel": BallModel,
                 "BallCandidates": BallCandidates,
                 "BallCandidatesTop": BallCandidatesTop,
+                "BehaviorStateComplete": BehaviorStateComplete,
+                "BehaviorStateSparse": BehaviorStateSparse,
                 "CameraMatrix": CameraMatrix,
                 "CameraMatrixTop": CameraMatrixTop,
                 "FieldPercept": FieldPercept,
@@ -139,7 +159,14 @@ class LogStatusClient:
                 "ShortLinePercept": ShortLinePercept,
                 "ScanLineEdgelPercept": ScanLineEdgelPercept,
                 "ScanLineEdgelPerceptTop": ScanLineEdgelPerceptTop,
+                "TeamMessageDecision": TeamMessageDecision,
+                "TeamState": TeamState,
                 "OdometryData": OdometryData,
+                "Image": Image,
+                "ImageTop": ImageTop,
+                "ImageJPEG": ImageJPEG,
+                "ImageJPEGTop": ImageJPEGTop,
+                "WhistlePercept": WhistlePercept,
                 "IMUData": IMUData,
                 "FSRData": FSRData,
                 "ButtonData": ButtonData,
@@ -149,12 +176,7 @@ class LogStatusClient:
                 "MotionStatus": MotionStatus,
                 "MotorJointData": MotorJointData,
                 "GyrometerData": GyrometerData,
-                "num_cognition_frames": num_cognition_frames,
                 "num_motion_frames": num_motion_frames,
-                "num_jpg_bottom": num_jpg_bottom,
-                "num_jpg_top": num_jpg_top,
-                "num_bottom": num_bottom,
-                "num_top": num_top,
             },
             request_options=request_options,
             omit=OMIT,
@@ -168,10 +190,11 @@ class LogStatusClient:
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
     def list(
-            self, 
-            #log_id: int, *, 
-            request_options: typing.Optional[RequestOptions] = None,
-            **filters: typing.Any) -> typing.List[LogStatus]:
+        self,
+        # log_id: int, *,
+        request_options: typing.Optional[RequestOptions] = None,
+        **filters: typing.Any,
+    ) -> typing.List[LogStatus]:
         """
         List all logs.
 
@@ -196,20 +219,27 @@ class LogStatusClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.log_status.list(log_id=1)
         ```
         """
         query_params = {k: v for k, v in filters.items() if v is not None}
-        _response = self._client_wrapper.httpx_client.request("api/log-status/", method="GET", request_options=request_options,params=query_params)
-        #_response = self._client_wrapper.httpx_client.request(
+        _response = self._client_wrapper.httpx_client.request(
+            "api/log-status/",
+            method="GET",
+            request_options=request_options,
+            params=query_params,
+        )
+        # _response = self._client_wrapper.httpx_client.request(
         #    f"api/cognitionrepr/?log={jsonable_encoder(log_id)}", method="GET", request_options=request_options
-        #)
+        # )
         try:
             if 200 <= _response.status_code < 300:
-                return pydantic_v1.parse_obj_as(typing.List[LogStatus], _response.json())  # type: ignore
+                return pydantic_v1.parse_obj_as(
+                    typing.List[LogStatus], _response.json()
+                )  # type: ignore
             _response_json = _response.json()
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
@@ -219,9 +249,14 @@ class LogStatusClient:
         self,
         *,
         log: typing.Optional[int] = OMIT,
+        FrameInfo: typing.Optional[int] = OMIT,
+        RobotInfo: typing.Optional[int] = OMIT,
+        AudioData: typing.Optional[int] = OMIT,
         BallModel: typing.Optional[int] = OMIT,
         BallCandidates: typing.Optional[int] = OMIT,
         BallCandidatesTop: typing.Optional[int] = OMIT,
+        BehaviorStateComplete: typing.Optional[int] = OMIT,
+        BehaviorStateSparse: typing.Optional[int] = OMIT,
         CameraMatrix: typing.Optional[int] = OMIT,
         CameraMatrixTop: typing.Optional[int] = OMIT,
         FieldPercept: typing.Optional[int] = OMIT,
@@ -234,7 +269,14 @@ class LogStatusClient:
         ShortLinePercept: typing.Optional[int] = OMIT,
         ScanLineEdgelPercept: typing.Optional[int] = OMIT,
         ScanLineEdgelPerceptTop: typing.Optional[int] = OMIT,
+        TeamMessageDecision: typing.Optional[int] = OMIT,
+        TeamState: typing.Optional[int] = OMIT,
         OdometryData: typing.Optional[int] = OMIT,
+        Image: typing.Optional[int] = OMIT,
+        ImageTop: typing.Optional[int] = OMIT,
+        ImageJPEG: typing.Optional[int] = OMIT,
+        ImageJPEGTop: typing.Optional[int] = OMIT,
+        WhistlePercept: typing.Optional[int] = OMIT,
         IMUData: typing.Optional[int] = OMIT,
         FSRData: typing.Optional[int] = OMIT,
         ButtonData: typing.Optional[int] = OMIT,
@@ -244,12 +286,7 @@ class LogStatusClient:
         MotionStatus: typing.Optional[int] = OMIT,
         MotorJointData: typing.Optional[int] = OMIT,
         GyrometerData: typing.Optional[int] = OMIT,
-        num_cognition_frames: typing.Optional[int] = OMIT,
         num_motion_frames: typing.Optional[int] = OMIT,
-        num_jpg_bottom: typing.Optional[int] = OMIT,
-        num_jpg_top: typing.Optional[int] = OMIT,
-        num_bottom: typing.Optional[int] = OMIT,
-        num_top: typing.Optional[int] = OMIT,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> LogStatus:
         """
@@ -266,19 +303,24 @@ class LogStatusClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         ```
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/log-status/",
+            "api/log-status/",
             method="POST",
             json={
                 "log": log,
+                "FrameInfo": FrameInfo,
+                "RobotInfo": RobotInfo,
+                "AudioData": AudioData,
                 "BallModel": BallModel,
                 "BallCandidates": BallCandidates,
                 "BallCandidatesTop": BallCandidatesTop,
+                "BehaviorStateComplete": BehaviorStateComplete,
+                "BehaviorStateSparse": BehaviorStateSparse,
                 "CameraMatrix": CameraMatrix,
                 "CameraMatrixTop": CameraMatrixTop,
                 "FieldPercept": FieldPercept,
@@ -291,7 +333,14 @@ class LogStatusClient:
                 "ShortLinePercept": ShortLinePercept,
                 "ScanLineEdgelPercept": ScanLineEdgelPercept,
                 "ScanLineEdgelPerceptTop": ScanLineEdgelPerceptTop,
+                "TeamMessageDecision": TeamMessageDecision,
+                "TeamState": TeamState,
                 "OdometryData": OdometryData,
+                "Image": Image,
+                "ImageTop": ImageTop,
+                "ImageJPEG": ImageJPEG,
+                "ImageJPEGTop": ImageJPEGTop,
+                "WhistlePercept": WhistlePercept,
                 "IMUData": IMUData,
                 "FSRData": FSRData,
                 "ButtonData": ButtonData,
@@ -301,12 +350,7 @@ class LogStatusClient:
                 "MotionStatus": MotionStatus,
                 "MotorJointData": MotorJointData,
                 "GyrometerData": GyrometerData,
-                "num_cognition_frames": num_cognition_frames,
                 "num_motion_frames": num_motion_frames,
-                "num_jpg_bottom": num_jpg_bottom,
-                "num_jpg_top": num_jpg_top,
-                "num_bottom": num_bottom,
-                "num_top": num_top,
             },
             request_options=request_options,
             omit=OMIT,
@@ -318,4 +362,3 @@ class LogStatusClient:
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
-
