@@ -12,41 +12,48 @@ from ..types.log import Log
 # this is used as the default value for optional parameters
 OMIT = typing.cast(typing.Any, ...)
 
+
 class LogClient:
     def __init__(self, *, client_wrapper: SyncClientWrapper):
         self._client_wrapper = client_wrapper
 
-    def get(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> Log:
+    def get(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> Log:
         """
         Examples
         --------
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/logs/{jsonable_encoder(id)}/", method="GET", request_options=request_options
+            f"api/logs/{jsonable_encoder(id)}/",
+            method="GET",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
                 return pydantic_v1.parse_obj_as(Log, _response.json())  # type: ignore
             _response_json = _response.json()
-            
+
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
-    def delete(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> None:
+    def delete(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> None:
         """
         Delete a Log., this will also delete all images and representations
 
         <Warning>This action can't be undone!</Warning>
 
-        You will need to supply the logs's unique ID. You can find the ID in 
-        the django admin panel or in the log settings in the UI. 
+        You will need to supply the logs's unique ID. You can find the ID in
+        the django admin panel or in the log settings in the UI.
         Parameters
         ----------
         id : int
@@ -64,7 +71,7 @@ class LogClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.annotations.delete(
@@ -72,7 +79,9 @@ class LogClient:
         )
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/logs/{jsonable_encoder(id)}/", method="DELETE", request_options=request_options
+            f"api/logs/{jsonable_encoder(id)}/",
+            method="DELETE",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
@@ -97,22 +106,17 @@ class LogClient:
         sensor_log_path: typing.Optional[str] = OMIT,
         log_path: typing.Optional[str] = OMIT,
         combined_log_path: typing.Optional[str] = OMIT,
-        num_cognition_frames: typing.Optional[int] = OMIT,
-        num_motion_frames: typing.Optional[int] = OMIT,
-        num_jpg_bottom: typing.Optional[int] = OMIT,
-        num_jpg_top: typing.Optional[int] = OMIT,
-        num_bottom: typing.Optional[int] = OMIT,
-        num_top: typing.Optional[int] = OMIT,
+        git_commit: typing.Optional[str] = OMIT,
+        is_favourite: typing.Optional[bool] = OMIT,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> Log:
-        """
-        """
+        """ """
         _response = self._client_wrapper.httpx_client.request(
             f"api/logs/{jsonable_encoder(id)}/",
             method="PATCH",
             json={
-                "log_game": game,
-                "log_experiment": experiment,
+                "game": game,
+                "experiment": experiment,
                 "robot_version": robot_version,
                 "player_number": player_number,
                 "head_number": head_number,
@@ -122,12 +126,8 @@ class LogClient:
                 "sensor_log_path": sensor_log_path,
                 "log_path": log_path,
                 "combined_log_path": combined_log_path,
-                "num_cognition_frames": num_cognition_frames,
-                "num_motion_frames": num_motion_frames,
-                "num_jpg_bottom": num_jpg_bottom,
-                "num_jpg_top": num_jpg_top,
-                "num_bottom": num_bottom,
-                "num_top": num_top,
+                "git_commit": git_commit,
+                "is_favourite": is_favourite,
             },
             request_options=request_options,
             omit=OMIT,
@@ -141,11 +141,12 @@ class LogClient:
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
     def list(
-             self, 
-             *, 
-             #game_id: typing.Optional[int] = None,
-             request_options: typing.Optional[RequestOptions] = None,
-             **filters: typing.Any) -> typing.List[Log]:
+        self,
+        *,
+        # game_id: typing.Optional[int] = None,
+        request_options: typing.Optional[RequestOptions] = None,
+        **filters: typing.Any,
+    ) -> typing.List[Log]:
         # TODO: maybe we should not allow filtering for arbitrary fields - makes validation hard and also filtering for json fields is not useful/possible
         """
         List all logs.
@@ -170,7 +171,7 @@ class LogClient:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.annotations.list(
@@ -178,15 +179,20 @@ class LogClient:
         )
         """
         query_params = {k: v for k, v in filters.items() if v is not None}
-        #if game_id:
+        # if game_id:
         #    _response = self._client_wrapper.httpx_client.request(
         #        f"api/logs/?game={jsonable_encoder(game_id)}", method="GET", request_options=request_options
         #    )
-        #else:
+        # else:
         #    _response = self._client_wrapper.httpx_client.request(
         #        f"api/logs/", method="GET", request_options=request_options
         #    )
-        _response = self._client_wrapper.httpx_client.request("api/logs/", method="GET", request_options=request_options,params=query_params)
+        _response = self._client_wrapper.httpx_client.request(
+            "api/logs/",
+            method="GET",
+            request_options=request_options,
+            params=query_params,
+        )
         try:
             if 200 <= _response.status_code < 300:
                 return pydantic_v1.parse_obj_as(typing.List[Log], _response.json())  # type: ignore
@@ -209,18 +215,13 @@ class LogClient:
         sensor_log_path: typing.Optional[str] = OMIT,
         log_path: typing.Optional[str] = OMIT,
         combined_log_path: typing.Optional[str] = OMIT,
-        num_cognition_frames: typing.Optional[int] = OMIT,
-        num_motion_frames: typing.Optional[int] = OMIT,
-        num_jpg_bottom: typing.Optional[int] = OMIT,
-        num_jpg_top: typing.Optional[int] = OMIT,
-        num_bottom: typing.Optional[int] = OMIT,
-        num_top: typing.Optional[int] = OMIT,
+        git_commit: typing.Optional[str] = OMIT,
+        is_favourite: typing.Optional[bool] = OMIT,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> Log:
-        """
-        """
+        """ """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/logs/",
+            "api/logs/",
             method="POST",
             json={
                 "game": game,
@@ -234,12 +235,8 @@ class LogClient:
                 "sensor_log_path": sensor_log_path,
                 "log_path": log_path,
                 "combined_log_path": combined_log_path,
-                "num_cognition_frames": num_cognition_frames,
-                "num_motion_frames": num_motion_frames,
-                "num_jpg_bottom": num_jpg_bottom,
-                "num_jpg_top": num_jpg_top,
-                "num_bottom": num_bottom,
-                "num_top": num_top,
+                "git_commit": git_commit,
+                "is_favourite": is_favourite,
             },
             request_options=request_options,
             omit=OMIT,
