@@ -10,7 +10,7 @@ class BehaviorOptionState(pydantic_v1.BaseModel):
     id: typing.Optional[int] = None
 
     #: Log ID: Id of related log / robot data
-    log_id: typing.Optional[int] = pydantic_v1.Field(default=None)
+    log: typing.Optional[int] = pydantic_v1.Field(default=None)
 
     #: option_id
     option_id: typing.Optional[int] = pydantic_v1.Field(default=None)
@@ -25,19 +25,32 @@ class BehaviorOptionState(pydantic_v1.BaseModel):
     target: typing.Optional[bool] = pydantic_v1.Field(default=None)
 
     def json(self, **kwargs: typing.Any) -> str:
-        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
+        kwargs_with_defaults: typing.Any = {
+            "by_alias": True,
+            "exclude_unset": True,
+            **kwargs,
+        }
         return super().json(**kwargs_with_defaults)
 
     def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
-        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
-        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}
+        kwargs_with_defaults_exclude_unset: typing.Any = {
+            "by_alias": True,
+            "exclude_unset": True,
+            **kwargs,
+        }
+        kwargs_with_defaults_exclude_none: typing.Any = {
+            "by_alias": True,
+            "exclude_none": True,
+            **kwargs,
+        }
 
         return deep_union_pydantic_dicts(
-            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
+            super().dict(**kwargs_with_defaults_exclude_unset),
+            super().dict(**kwargs_with_defaults_exclude_none),
         )
 
     class Config:
         frozen = True
         smart_union = True
         extra = pydantic_v1.Extra.allow
-        json_encoders = {dt.datetime: serialize_datetime}
\ No newline at end of file
+        json_encoders = {dt.datetime: serialize_datetime}
