@@ -7,28 +7,43 @@ from ..core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
 
 class MotionFrame(pydantic_v1.BaseModel):
     #: Foreign key to the log the image belongs to
-    log_id: typing.Optional[int] = pydantic_v1.Field(default=None)
-    
+    log: typing.Optional[int] = pydantic_v1.Field(default=None)
+
     #: Frame Number
     frame_number: typing.Optional[int] = None
 
     #
     frame_time: typing.Optional[int] = None
 
+    closest_cognition_frame: typing.Optional[int] = pydantic_v1.Field(default=None)
+
     def json(self, **kwargs: typing.Any) -> str:
-        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
+        kwargs_with_defaults: typing.Any = {
+            "by_alias": True,
+            "exclude_unset": True,
+            **kwargs,
+        }
         return super().json(**kwargs_with_defaults)
 
     def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
-        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
-        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}
+        kwargs_with_defaults_exclude_unset: typing.Any = {
+            "by_alias": True,
+            "exclude_unset": True,
+            **kwargs,
+        }
+        kwargs_with_defaults_exclude_none: typing.Any = {
+            "by_alias": True,
+            "exclude_none": True,
+            **kwargs,
+        }
 
         return deep_union_pydantic_dicts(
-            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
+            super().dict(**kwargs_with_defaults_exclude_unset),
+            super().dict(**kwargs_with_defaults_exclude_none),
         )
 
     class Config:
         frozen = True
         smart_union = True
         extra = pydantic_v1.Extra.allow
-        json_encoders = {dt.datetime: serialize_datetime}
\ No newline at end of file
+        json_encoders = {dt.datetime: serialize_datetime}
