@@ -11,25 +11,27 @@ from ..types.xabsl_symbol_sparse import XabslSymbolSparse
 # this is used as the default value for optional parameters
 OMIT = typing.cast(typing.Any, ...)
 
+
 class XabslSymbolClientSparse:
     """Wrapper for interacting with the XabslSymbolSparse Table of the database.
-    
+
     This class provides methods to interact with XabslSymbolSparse entries
     in the database through the API.
-    
+
     Parameters
     ----------
     client_wrapper : SyncClientWrapper
         The client wrapper instance used for making HTTP requests.
-    
+
     Attributes
     ----------
     _client_wrapper : SyncClientWrapper
         Internal reference to the client wrapper.
     """
+
     def __init__(self, *, client_wrapper: SyncClientWrapper):
         """Initialize the XabslSymbolClientSparse.
-        
+
         Parameters
         ----------
         client_wrapper : SyncClientWrapper
@@ -37,7 +39,9 @@ class XabslSymbolClientSparse:
         """
         self._client_wrapper = client_wrapper
 
-    def get(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> XabslSymbolSparse:
+    def get(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> XabslSymbolSparse:
         """Retrieve an XabslSymbolSparse entry by its ID.
 
         Parameters
@@ -46,7 +50,7 @@ class XabslSymbolClientSparse:
             The unique identifier of the XabslSymbolSparse entry.
         request_options : RequestOptions, optional
             Additional options for the HTTP request.
-            
+
         Returns
         -------
         XabslSymbolSparse
@@ -63,27 +67,31 @@ class XabslSymbolClientSparse:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
-         
+
         symbol = client.behavior.symbol.sparse.get(id=123)
         ```
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/behavior/symbol/sparse/{jsonable_encoder(id)}/", method="GET", request_options=request_options
+            f"api/behavior/symbol/sparse/{jsonable_encoder(id)}/",
+            method="GET",
+            request_options=request_options,
         )
 
         try:
             if 200 <= _response.status_code < 300:
                 return pydantic_v1.parse_obj_as(XabslSymbolSparse, _response.json())  # type: ignore
             _response_json = _response.json()
-            
+
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
-    def delete(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> None:
+    def delete(
+        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
+    ) -> None:
         """
         Delete a Xabsl Symbol from the XabslSymbolSparse Table.
 
@@ -107,7 +115,7 @@ class XabslSymbolClientSparse:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.xabsl_symbol_sparse.delete(
@@ -116,7 +124,9 @@ class XabslSymbolClientSparse:
         ```
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/behavior/symbol/sparse/{jsonable_encoder(id)}/", method="DELETE", request_options=request_options
+            f"api/behavior/symbol/sparse/{jsonable_encoder(id)}/",
+            method="DELETE",
+            request_options=request_options,
         )
         try:
             if 200 <= _response.status_code < 300:
@@ -138,62 +148,62 @@ class XabslSymbolClientSparse:
         request_options: typing.Optional[RequestOptions] = None,
     ) -> XabslSymbolSparse:
         """
-        Update attributes for an existing annotation.
+         Update attributes for an existing annotation.
 
-        You will need to supply the annotation's unique ID. You can find the ID in the Label Studio UI listed at the top of the annotation in its tab. It is also listed in the History panel when viewing the annotation. Or you can use [Get all task annotations](list) to find all annotation IDs.
+         You will need to supply the annotation's unique ID. You can find the ID in the Label Studio UI listed at the top of the annotation in its tab. It is also listed in the History panel when viewing the annotation. Or you can use [Get all task annotations](list) to find all annotation IDs.
 
-        For information about the JSON format used in the result, see [Label Studio JSON format of annotated tasks](https://labelstud.io/guide/export#Label-Studio-JSON-format-of-annotated-tasks).
+         For information about the JSON format used in the result, see [Label Studio JSON format of annotated tasks](https://labelstud.io/guide/export#Label-Studio-JSON-format-of-annotated-tasks).
 
-        Parameters
-        ----------
-        id : int
-            A unique integer value identifying this annotation.
+         Parameters
+         ----------
+         id : int
+             A unique integer value identifying this annotation.
 
-        result : typing.Optional[typing.Sequence[typing.Dict[str, typing.Any]]]
-            Labeling result in JSON format. Read more about the format in [the Label Studio documentation.](https://labelstud.io/guide/task_format)
+         result : typing.Optional[typing.Sequence[typing.Dict[str, typing.Any]]]
+             Labeling result in JSON format. Read more about the format in [the Label Studio documentation.](https://labelstud.io/guide/task_format)
 
-        task : typing.Optional[int]
-            Corresponding task for this annotation
+         task : typing.Optional[int]
+             Corresponding task for this annotation
 
-        project : typing.Optional[int]
-            Project ID for this annotation
+         project : typing.Optional[int]
+             Project ID for this annotation
 
-        completed_by : typing.Optional[int]
-            User ID of the person who created this annotation
+         completed_by : typing.Optional[int]
+             User ID of the person who created this annotation
 
-        updated_by : typing.Optional[int]
-            Last user who updated this annotation
+         updated_by : typing.Optional[int]
+             Last user who updated this annotation
 
-        was_cancelled : typing.Optional[bool]
-            User skipped the task
+         was_cancelled : typing.Optional[bool]
+             User skipped the task
 
-        ground_truth : typing.Optional[bool]
-            This annotation is a Ground Truth
+         ground_truth : typing.Optional[bool]
+             This annotation is a Ground Truth
 
-        lead_time : typing.Optional[float]
-            How much time it took to annotate the task (in seconds)
+         lead_time : typing.Optional[float]
+             How much time it took to annotate the task (in seconds)
 
-        request_options : typing.Optional[RequestOptions]
-            Request-specific configuration.
+         request_options : typing.Optional[RequestOptions]
+             Request-specific configuration.
 
-        Returns
-        -------
-        Annotation
-            Updated annotation
+         Returns
+         -------
+         Annotation
+             Updated annotation
 
-       Examples
-        --------
-        ```python
-        from vaapi.client import Vaapi
+        Examples
+         --------
+         ```python
+         from vaapi.client import Vaapi
 
-        client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
-            api_key="YOUR_API_KEY",
-        )
-        client.xabsl_symbol_sparse.update(
-            id=1,
-        )
-        ```
+         client = Vaapi(
+             base_url='https://vat.berlin-united.com/',
+             api_key="YOUR_API_KEY",
+         )
+         client.xabsl_symbol_sparse.update(
+             id=1,
+         )
+         ```
         """
         _response = self._client_wrapper.httpx_client.request(
             f"api/behavior/symbol/sparse/{jsonable_encoder(id)}/",
@@ -217,10 +227,11 @@ class XabslSymbolClientSparse:
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
     def list(
-            self, 
-            #log_id: int, *, 
-            request_options: typing.Optional[RequestOptions] = None,
-            **filters: typing.Any) -> typing.List[XabslSymbolSparse]:
+        self,
+        # log_id: int, *,
+        request_options: typing.Optional[RequestOptions] = None,
+        **filters: typing.Any,
+    ) -> typing.List[XabslSymbolSparse]:
         """
         List XabslSymbolSparse with or without filters.
 
@@ -245,7 +256,7 @@ class XabslSymbolClientSparse:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.xabsl_symbol_sparse.list(
@@ -254,11 +265,18 @@ class XabslSymbolClientSparse:
         ```
         """
         query_params = {k: v for k, v in filters.items() if v is not None}
-        _response = self._client_wrapper.httpx_client.request("api/xabsl-symbol/", method="GET", request_options=request_options,params=query_params)
+        _response = self._client_wrapper.httpx_client.request(
+            "api/xabsl-symbol/",
+            method="GET",
+            request_options=request_options,
+            params=query_params,
+        )
 
         try:
             if 200 <= _response.status_code < 300:
-                return pydantic_v1.parse_obj_as(typing.List[XabslSymbolSparse], _response.json())  # type: ignore
+                return pydantic_v1.parse_obj_as(
+                    typing.List[XabslSymbolSparse], _response.json()
+                )  # type: ignore
             _response_json = _response.json()
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
@@ -291,7 +309,7 @@ class XabslSymbolClientSparse:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.xabsl_symbol_sparse.create(
@@ -300,7 +318,7 @@ class XabslSymbolClientSparse:
         ```
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/behavior/symbol/sparse/",
+            "api/behavior/symbol/sparse/",
             method="POST",
             json={
                 "log_id": log_id,
@@ -318,7 +336,6 @@ class XabslSymbolClientSparse:
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
         raise ApiError(status_code=_response.status_code, body=_response_json)
-    
 
     def bulk_create(
         self,
@@ -345,7 +362,7 @@ class XabslSymbolClientSparse:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.xabsl_symbol_sparse.bulk_create(
@@ -354,7 +371,7 @@ class XabslSymbolClientSparse:
         ```
         """
         _response = self._client_wrapper.httpx_client.request(
-            f"api/behavior/symbol/sparse/",
+            "api/behavior/symbol/sparse/",
             method="POST",
             json=data,
             request_options=request_options,
@@ -369,9 +386,10 @@ class XabslSymbolClientSparse:
         raise ApiError(status_code=_response.status_code, body=_response_json)
 
     def get_behavior_count(
-            self,
-            request_options: typing.Optional[RequestOptions] = None,
-            **filters: typing.Any) -> typing.Optional[int]:
+        self,
+        request_options: typing.Optional[RequestOptions] = None,
+        **filters: typing.Any,
+    ) -> typing.Optional[int]:
         """
         Parameters
         ----------
@@ -391,7 +409,7 @@ class XabslSymbolClientSparse:
         from vaapi.client import Vaapi
 
         client = Vaapi(
-            base_url='https://vat.berlin-united.com/',  
+            base_url='https://vat.berlin-united.com/',
             api_key="YOUR_API_KEY",
         )
         client.xabsl_symbol_sparse.get_behavior_count(
@@ -400,11 +418,18 @@ class XabslSymbolClientSparse:
         ```
         """
         query_params = {k: v for k, v in filters.items() if v is not None}
-        _response = self._client_wrapper.httpx_client.request("api/behavior/symbol/count/", method="GET", request_options=request_options,params=query_params)
+        _response = self._client_wrapper.httpx_client.request(
+            "api/behavior/symbol/count/",
+            method="GET",
+            request_options=request_options,
+            params=query_params,
+        )
         try:
             if 200 <= _response.status_code < 300:
-                return pydantic_v1.parse_obj_as(typing.Dict[str, typing.Any], _response.json())  # type: ignore
+                return pydantic_v1.parse_obj_as(
+                    typing.Dict[str, typing.Any], _response.json()
+                )  # type: ignore
             _response_json = _response.json()
         except JSONDecodeError:
             raise ApiError(status_code=_response.status_code, body=_response.text)
-        raise ApiError(status_code=_response.status_code, body=_response_json)
\ No newline at end of file
+        raise ApiError(status_code=_response.status_code, body=_response_json)
